Module: RoundhouseUi::ObservabilityHelper
- Defined in:
- app/helpers/roundhouse_ui/observability_helper.rb
Instance Method Summary collapse
-
#trace_link(klass:, jid:, queue: nil) ⇒ Object
Renders a deep-link to the configured observability tool for a job, or nothing when no adapter is configured (the default).
Instance Method Details
#trace_link(klass:, jid:, queue: nil) ⇒ Object
Renders a deep-link to the configured observability tool for a job, or nothing when no adapter is configured (the default).
5 6 7 8 9 10 11 |
# File 'app/helpers/roundhouse_ui/observability_helper.rb', line 5 def trace_link(klass:, jid:, queue: nil) adapter = RoundhouseUi.observability url = adapter.job_url(klass: klass, jid: jid, queue: queue) return unless url link_to "↗ #{adapter.label}", url, target: "_blank", rel: "noopener", class: "rh-trace" end |